==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/OutageEntryBuilder.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OutageEntryBuilder extends io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryFluentImpl<io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntry,io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryBuilder>{
  public OutageEntryBuilder() {
    this(false);
  }
  public OutageEntryBuilder(java.lang.Boolean validationEnabled) {
    this(new OutageEntry(), validationEnabled);
  }
  public OutageEntryBuilder(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryFluent<?> fluent) {
    this(fluent, false);
  }
  public OutageEntryBuilder(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OutageEntry(), validationEnabled);
  }
  public OutageEntryBuilder(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryFluent<?> fluent,io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntry instance) {
    this(fluent, instance, false);
  }
  public OutageEntryBuilder(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryFluent<?> fluent,io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntry instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnd(instance.getEnd()); 
    fluent.withEndLogs(instance.getEndLogs()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withStart(instance.getStart()); 
    fluent.withStartLogs(instance.getStartLogs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OutageEntryBuilder(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntry instance) {
    this(instance,false);
  }
  public OutageEntryBuilder(io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntry instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnd(instance.getEnd()); 
    this.withEndLogs(instance.getEndLogs()); 
    this.withMessage(instance.getMessage()); 
    this.withStart(instance.getStart()); 
    this.withStartLogs(instance.getStartLogs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntryFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.controlplane.v1alpha1.OutageEntry build() {
    OutageEntry buildable = new OutageEntry(fluent.getEnd(),fluent.getEndLogs(),fluent.getMessage(),fluent.getStart(),fluent.getStartLogs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OutageEntryBuilder that = (OutageEntryBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.6.0-sources.jar: io/fabric8/openshift/api/model/operator/controlplane/v1alpha1/OutageEntryBuilder.java <==
package io.fabric8.openshift.api.model.operator.controlplane.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OutageEntryBuilder extends OutageEntryFluentImpl<OutageEntryBuilder> implements VisitableBuilder<OutageEntry,OutageEntryBuilder>{
  public OutageEntryBuilder() {
    this(false);
  }
  public OutageEntryBuilder(Boolean validationEnabled) {
    this(new OutageEntry(), validationEnabled);
  }
  public OutageEntryBuilder(OutageEntryFluent<?> fluent) {
    this(fluent, false);
  }
  public OutageEntryBuilder(OutageEntryFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OutageEntry(), validationEnabled);
  }
  public OutageEntryBuilder(OutageEntryFluent<?> fluent,OutageEntry instance) {
    this(fluent, instance, false);
  }
  public OutageEntryBuilder(OutageEntryFluent<?> fluent,OutageEntry instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnd(instance.getEnd()); 
    fluent.withEndLogs(instance.getEndLogs()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withStart(instance.getStart()); 
    fluent.withStartLogs(instance.getStartLogs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OutageEntryBuilder(OutageEntry instance) {
    this(instance,false);
  }
  public OutageEntryBuilder(OutageEntry instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnd(instance.getEnd()); 
    this.withEndLogs(instance.getEndLogs()); 
    this.withMessage(instance.getMessage()); 
    this.withStart(instance.getStart()); 
    this.withStartLogs(instance.getStartLogs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  OutageEntryFluent<?> fluent;
  Boolean validationEnabled;
  public OutageEntry build() {
    OutageEntry buildable = new OutageEntry(fluent.getEnd(),fluent.getEndLogs(),fluent.getMessage(),fluent.getStart(),fluent.getStartLogs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
